/*
 * @kgsIORead.java Version 1.1 10/19/2007
 *
 * Copyright (c) 2007 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package kgs.io;

import java.io.*;
import java.awt.*;
import javax.swing.*;

import iqstrat.iqstratHeadersStruct;
import iqstrat.iqstratHeadersListStruct;
import iqstrat.io.ReadHeadersXMLFile;

import xml.ReadLASFileXMLFile;
import cmn.cmnLASFileListStruct;

/** Class kgsIORead
 *  <p> This Class will retrieve the Oil & Gas Well Data from the KGS Database.
 *      This class will retrieve the following information,
 *
 *      - LAS File Information by API-Number
 *      - Formation Regions, Tops, Perforation zones, DST Measurements
 *      - Measured Core Data
 *      - Core Images
 *
 *  @version 1.1 10/19/2007
 *  @author  John R. Victorine
 */

public class kgsIORead
{
  /** Constructor kgsIORead()
   *  <p> This is the Constructor for this class.
   */

  public kgsIORead() { }

  /* ===================================================================== *
   * ---------------------------- XML Methods ---------------------------- *
   * ===================================================================== */

  /** Method getData()
   * <p> This method will read the User information xml data
   * @param  iMethod = The Method used in retrieving the XML
   * @param  sPath   = The url or File Path to use
   * @return stUser  = The User Data Structure
   */

  public static iqstratHeadersListStruct getData(int iMethod, String sPath)
  {
    iqstratHeadersListStruct st = null; // headers Information Data Structure

    ReadHeadersXMLFile pLocInfo = new ReadHeadersXMLFile(iMethod);
    st = pLocInfo.Process(sPath);

    String sError = pLocInfo.GetError();
    if (sError.length() > 0)
      JOptionPane.showMessageDialog( (Component)null,
                                     sError,
                                     "ERROR",
                                     JOptionPane.ERROR_MESSAGE);

    return (st);
  }

  /** Method ReadLASFileInformation()
   * <p> This method will retrieve the LAS File Information
   *     for a specific well from the database
   * @param  sAPI    = API-Number of the Well.
   * @param  iMethod = The Method used in retrieving the XML
   * @return st  = The LAS File Information Data
   */

  public static cmnLASFileListStruct ReadLASFileInformation(String sAPI,
                                                            int    iMethod)
  {
    cmnLASFileListStruct st = new cmnLASFileListStruct();

    ReadLASFileXMLFile pXML = new ReadLASFileXMLFile(iMethod);
    st = pXML.Process(cmn.cmnStruct.KGS_LAS_FILES + "sAPI=" + sAPI);

    return (st);
  }
}