/*
 * @lasFileDataStruct.java Version 1.1 09/05/2007
 *
 * Copyright (c) 2007 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package las;

//import iqstrat.iqstratShaleListStruct;
import las3.las3Struct;

/** Class lasFileDataStruct
 *  <p> This Class holds the LAS File Well Data.
 *
 *  @version 1.1 09/05/2007
 *  @author  John R. Victorine
 */

public class lasFileDataStruct
{
  public int    iSource    = las3.las3Constants._SOURCE_NONE;

  // Well Information Data

  public String sKID       = "";  // Primary Key for the KGS Well
  public String sKEY       = "";  // Primary Key created by user
  public int    iType      = iqstrat.iqstratHeadersStruct.WELL; // Type of Data

  public String sAPI       = "";  // API-Number of Well
  public String sName      = "";  // Well Name
  public String state      = "";  // State Name
  public String sCounty    = "";  // County Name
  public String status     = "";  // Status of Well, i.e., OIL, GAS, etc.

  public double dLatitude  = 0.0; // Latitude of Well
  public double dLongitude = 0.0; // Longitude of Well

  public double dKB        = 0.0; // Kelly Bushing of Well
  public double dGL        = 0.0; // Ground Level of Well
  public double dTD        = 0.0; // Total Depth of Well

  // LAS File Information

  public String sReadMethod  = "";  // File Read Method
  public String sDirectory   = "";  // Directory Path to the LAS File
  public String sFilename    = "";  // File name of LAS File
  public String sVersion     = "";  // LAS Version Number

  public double dNull        = -999.95; // Default Null Value of Data
  public double depthStart   = 0.0;     // Start Depth of LAS Data
  public double depthEnd     = 0.0;     // Ending Depth of LAS Data
  public double depthStep    = 0.0;     // Depth Step of LAS DAta

  public double dTimeStart   = 0.0;     // Start Time of LAS Data
  public double dTimeEnd     = 0.0;     // Ending Time of LAS Data

  public int    iProprietary = 0; // Proprietary Data Identfier

  // LAS 3 File Parameters

  // -- Required Parameters

  public String sPDAT      = "";    // Permanent Data
  public double dAPD       = 0.0;   // Above Permanent Data
  public String sDREF      = "";    // Depth Reference (KB,DF,CB)
  public double dElevation = 0.0;   // "Elevation of Depth Reference"

  // -- Required parameters for AEUB compliance

  public double dTDD       = 0.0;   // Drillers Depth
  public double dTLD       = 0.0;   // Loggers Depth
  public double dCSGL      = 0.0;   // Casing Bottom Logger
  public double dCSGD      = 0.0;   // Casing Bottom Driller
  public double dCSGS      = 0.0;   // Casing Size
  public double dCSGW      = 0.0;   // Casing Weight
  public double dBS        = 0.0;   // Bit Size
  public String sMUD       = "";    // Mud type
  public String sMUDS      = "";    // Mud Source
  public double dMUDD      = 0.0;   // Mud Density
  public double dMUDV      = 0.0;   // Mud Viscosity (Funnel)
  public double dFL        = 0.0;   // Fluid Loss
  public double dPH        = 0.0;   // PH
  public double dRM        = 0.0;   // Resistivity of Mud
  public double dRMT       = 0.0;   // Temperature of Mud
  public double dRMF       = 0.0;   //  Rest. of Mud Filtrate
  public double dRMFT      = 0.0;   // Temp. of Mud Filtrate
  public double dRMC       = 0.0;   // Rest. of Mud Cake
  public double dRMCT      = 0.0;   // Temp. of Mud Cake
  public double dTMAX      = 0.0;   // Max. Recorded Temp.
  public String sTIMC      = "";    // Date/Time Circulation Stopped
  public String sTIML      = "";    // Date/Time Logger Tagged Bottom
  public String sUNIT      = "";    // Logging Unit Number
  public String sBASE      = "";    // Home Base of Logging Unit
  public String sENG       = "";    // Recording Engineer
  public String sWIT       = "";    // Witnessed By

  // .. Units for Required parameters for AEUB compliance

  public String sCSGL      = "";    // Casing Bottom Logger
  public String sCSGD      = "";    // Casing Bottom Driller
  public String sCSGS      = "";    // Casing Size
  public String sCSGW      = "";    // Casing Weight
  public String sBS        = "";    // Bit Size
  public String sMUDD      = "";    // Mud Density
  public String sMUDV      = "";    // Mud Viscosity (Funnel)
  public String sFL        = "";    // Fluid Loss
  public String sRM        = "";    // Resistivity of Mud
  public String sRMT       = "";    // Temperature of Mud
  public String sRMF       = "";    //  Rest. of Mud Filtrate
  public String sRMFT      = "";    // Temp. of Mud Filtrate
  public String sRMC       = "";    // Rest. of Mud Cake
  public String sRMCT      = "";    // Temp. of Mud Cake
  public String sTMAX      = "";    // Max. Recorded Temp.

  // LAS 3 Data Structure without the data section

  public int        iLogs    = 0;
  public las3Struct stLAS3[] = null;

  public int    iParamRows  = 0;      // Total number of rows
  public int    iParamCols  = las3.las3Struct._TOTAL; // Total number of columns
  public String sParams[][] = null;   // Array holding the Parameter Definitions

  // Unknown Curve Mnemonics

  public String sUnknown[][] = {
    {"", ""},
    {"", ""},
    {"", ""},
    {"", ""},
  };

  // LAS File Curve Information

  public int    iColorlithDefault = -1;

  public int    iCAL1    = -1;
  public int    iCAL2    = -1;
  public int    iCAL3    = -1;
  public int    iCAL4    = -1;
  public int    iCAL5    = -1;
  public int    iCAL6    = -1;

  public int    iAZIC1   = -1;

  public int    iRows    = 0;    // Number of Rows
  public double depths[] = null; // Array of Depth Data Values

  public double dCAL1[]  = null; // Array of Caliper 1 Log Values
  public double dCAL2[]  = null; // Array of Caliper 2 Log Values
  public double dCAL3[]  = null; // Array of Caliper 3 Log Values
  public double dCAL4[]  = null; // Array of Caliper 4 Log Values
  public double dCAL5[]  = null; // Array of Caliper 5 Log Values
  public double dCAL6[]  = null; // Array of Caliper 6 Log Values

  public double dAZIC1[] = null; // Array of Azimuth degrees for pad 1 Log Values

  /** Method delete()
   * <p> This method will set the arrays and strings to null to force Java to
   *     deallocate memory
   */

  public void delete()
  {
    sKID       = null; // primary key by KGS db
    sKEY       = null; // Primary Key by user
    sAPI       = null; // API-Number of Well
    sName      = null; // Well Name

      // Other Fields not really displayed

    sCounty    = null; // County Name
    state      = null; // State Name

      // Well Location Information

    dLatitude  = 0.0; // Latitude of Well
    dLongitude = 0.0; // Longitude of Well

      // Well Parameter Information

    dKB        = 0.0; // Kelly Bushing of Well
    dGL        = 0.0; // Ground Level of Well
    dTD        = 0.0; // Total Depth of Well

      // Well Status

    status     = null; // Status of Well

    // LAS File Information

    sReadMethod  = null;  // File Read Method
    sDirectory   = null;  // Directory Path to the LAS File
    sFilename    = null;  // File name of LAS File
    sVersion     = null;  // LAS Version Number

    dNull        = 0.0; // Null Value of Data
    depthStart   = 0.0; // Start Depth of LAS Data
    depthEnd     = 0.0; // Ending Depth of LAS Data
    depthStep    = 0.0; // Depth Step of LAS DAta

    iProprietary = 0; // Proprietary Data Identfier

    // -- Required Parameters

    sPDAT      = null; // Permanent Data
    dAPD       = 0.0;  // Above Permanent Data
    sDREF      = null; // Depth Reference (KB,DF,CB)
    dElevation = 0.0;  // "Elevation of Depth Reference"

    // -- Required parameters for AEUB compliance

    dTDD    = 0.0;  // Drillers Depth
    dTLD    = 0.0;  // Loggers Depth

    dCSGL   = 0.0;  // Casing Bottom Logger
    dCSGD   = 0.0;  // Casing Bottom Driller
    dCSGS   = 0.0;  // Casing Size
    dCSGW   = 0.0;  // Casing Weight
    dBS     = 0.0;  // Bit Size

    sMUD    = null; // Mud type
    sMUDS   = null; // Mud Source
    dMUDD   = 0.0;  // Mud Density
    dMUDV   = 0.0;  // Mud Viscosity (Funnel)

    dFL     = 0.0;  // Fluid Loss
    dPH     = 0.0;  // PH

    dRM     = 0.0;  // Resistivity of Mud
    dRMT    = 0.0;  // Temperature of Mud
    dRMF    = 0.0;  // Resistivity of Mud Filtrate
    dRMFT   = 0.0;  // Temperature of Mud Filtrate
    dRMC    = 0.0;  // Resistivity of Mud Cake
    dRMCT   = 0.0;  // Temperature of Mud Cake
    dTMAX   = 0.0;  // Maximum Recorded Temp.

    sTIMC   = null; // Date/Time Circulation Stopped
    sTIML   = null; // Date/Time Logger Tagged Bottom
    sUNIT   = null; // Logging Unit Number
    sBASE   = null; // Home Base of Logging Unit
    sENG    = null; // Recording Engineer
    sWIT    = null; // Witnessed By

    // .. Units for Required parameters for AEUB compliance

    sCSGL   = null; // Casing Bottom Logger
    sCSGD   = null; // Casing Bottom Driller
    sCSGS   = null; // Casing Size
    sCSGW   = null; // Casing Weight
    sBS     = null; // Bit Size
    sMUDD   = null; // Mud Density
    sMUDV   = null; // Mud Viscosity (Funnel)
    sFL     = null; // Fluid Loss
    sRM     = null; // Resistivity of Mud
    sRMT    = null; // Temperature of Mud
    sRMF    = null; //  Rest. of Mud Filtrate
    sRMFT   = null; // Temp. of Mud Filtrate
    sRMC    = null; // Rest. of Mud Cake
    sRMCT   = null; // Temp. of Mud Cake
    sTMAX   = null; // Max. Recorded Temp.

    // LAS 3 File Parameters

    if (iLogs > 0)
    {
      for (int i=0; i<iLogs; i++)
      {
        if (stLAS3[i] != null)
          stLAS3[i].delete();
        stLAS3[i] = null;
      }
    }

    iParamRows = 0;    // Total number of rows
    iParamCols = 0;    // Total number of columns
    sParams    = null; // Array holding the Parameter Definitions

    // LAS File Curve Information

    iColorlithDefault = -1; // Default colorlith setting

    iCAL1       = -1;
    iCAL2       = -1;
    iCAL3       = -1;
    iCAL4       = -1;
    iCAL5       = -1;
    iCAL6       = -1;

    iAZIC1      = -1;

    iRows     = 0;    // Number of Rows
    depths    = null; // Array of Depth Data Values

    dCAL1     = null; // Array of Caliper 1 Log Values
    dCAL2     = null; // Array of Caliper 2 Log Values
    dCAL3     = null; // Array of Caliper 3 Log Values
    dCAL4     = null; // Array of Caliper 4 Log Values
    dCAL5     = null; // Array of Caliper 5 Log Values
    dCAL6     = null; // Array of Caliper 6 Log Values

    dAZIC1    = null; // Array of Azimuth degrees for pad 1 Log Values
  }

  /** Method checkData(int iCurve)
   * <p> This method will check to see if the curve data is present
   * @param  iCurve = the requested curve type
   * @return bvalue = true data exist, false data does not exist
   */

  public boolean checkData(int iCurve)
  {
    boolean bValue = false;
    int     data   = -1;

    switch (iCurve)
    {
      case las.lasStandardTools._CAL1:
        data = iCAL1;
        break;
      case las.lasStandardTools._CAL2:
        data = iCAL2;
        break;
      case las.lasStandardTools._CAL3:
        data = iCAL3;
        break;
      case las.lasStandardTools._CAL4:
        data = iCAL4;
        break;
      case las.lasStandardTools._CAL5:
        data = iCAL5;
        break;
      case las.lasStandardTools._CAL6:
        data = iCAL6;
        break;

      case las.lasStandardTools._AZIC1:
        data = iAZIC1;
        break;
	}

    if (data > -1)
      bValue = true;

    return (bValue);
  }


  /** Method getData(int iCurve)
   * <p> This method will retrive the curve data requested
   * @param  iCurve = the requested curve type
   * @return data   = the data requested.
   */

  public double[] getData(int iCurve)
  {
    double data[] = null;

    if (iRows > 0)
    {
      data = new double[iRows];

      switch (iCurve)
      {
        case las.lasStandardTools._CAL1:
          data = dCAL1;
          break;
        case las.lasStandardTools._CAL2:
          data = dCAL2;
          break;
        case las.lasStandardTools._CAL3:
          data = dCAL3;
          break;
        case las.lasStandardTools._CAL4:
          data = dCAL4;
          break;
        case las.lasStandardTools._CAL5:
          data = dCAL5;
          break;
        case las.lasStandardTools._CAL6:
          data = dCAL6;
          break;

        case las.lasStandardTools._AZIC1:
          data = dAZIC1;
          break;
      }
    }

    return (data);
  }

  /** Method getRow(int iCurve, int iRow)
   * <p> This method will retrive the curve data requested
   * @param  iCurve  = the requested curve type
   * @param  iRow    = The LAS Row
   * @return data    = the data requested.
   */

  public double getRow(int iCurve, int iRow)
  {
    double data = dNull;

    if (iRows > 0)
    {
      switch (iCurve)
      {
        case las.lasStandardTools._CAL1:
          data = dCAL1[iRow];
          break;
        case las.lasStandardTools._CAL2:
          data = dCAL2[iRow];
          break;
        case las.lasStandardTools._CAL3:
          data = dCAL3[iRow];
          break;
        case las.lasStandardTools._CAL4:
          data = dCAL4[iRow];
          break;
        case las.lasStandardTools._CAL5:
          data = dCAL5[iRow];
          break;
        case las.lasStandardTools._CAL6:
          data = dCAL6[iRow];
          break;

        case las.lasStandardTools._AZIC1:
          data = dAZIC1[iRow];
          break;
      }
    }

    return (data);
  }

  /** Method checkData(int iCurve)
   * <p> This method will check to see if the curve data is present
   * @param  iCurve  = the requested curve type
   * @param  iColumn = the column number for rock data
   */

  public void setData(int iCurve, int iColumn)
  {
    switch (iCurve)
    {
      case las.lasStandardTools._CAL1:
        iCAL1 = iColumn;
        break;
      case las.lasStandardTools._CAL2:
        iCAL2 = iColumn;
        break;
      case las.lasStandardTools._CAL3:
        iCAL3 = iColumn;
        break;
      case las.lasStandardTools._CAL4:
        iCAL4 = iColumn;
        break;
      case las.lasStandardTools._CAL5:
        iCAL5 = iColumn;
        break;
      case las.lasStandardTools._CAL6:
        iCAL6 = iColumn;
        break;

      case las.lasStandardTools._AZIC1:
        iAZIC1 = iColumn;
        break;
    }
  }


  /** Method setRow(int iCurve, int iRow, double data)
   * <p> This method will set the curve data requested
   * @param  iCurve  = the requested curve type
   * @param  iRow    = The LAS Row
   * @param  data    = the data being modified.
   */

  public void setRow(int iCurve, int iRow, double data)
  {
    if (iRows > 0)
    {
      switch (iCurve)
      {
        case las.lasStandardTools._CAL1:
          dCAL1[iRow] = data;
          break;
        case las.lasStandardTools._CAL2:
          dCAL2[iRow] = data;
          break;
        case las.lasStandardTools._CAL3:
          dCAL3[iRow] = data;
          break;
        case las.lasStandardTools._CAL4:
          dCAL4[iRow] = data;
          break;
        case las.lasStandardTools._CAL5:
          dCAL5[iRow] = data;
          break;
        case las.lasStandardTools._CAL6:
          dCAL6[iRow] = data;
          break;

        case las.lasStandardTools._AZIC1:
          dAZIC1[iRow] = data;
          break;
      }
    }
  }
}