/*
 * @lasFileDataUtility.java Version 1.1 09/05/2007
 *
 * Copyright (c) 2007 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package las;

import las.lasFileDataStruct;
import las.lasDataListStruct;
import las3.las3Struct;

import iqstrat.iqstratHeadersStruct;

import cmn.cmnLASCurveListStruct;

/** Class lasFileDataUtility
 *  <p> This Class will provide basic utilities for the LAS Curves
 *      data structures.
 *
 *  @version 1.1 09/05/2007
 *  @author  John R. Victorine
 */

public class lasFileDataUtility
{
  /** Method copy()
   * <p> This method will copy only the LAS3 Variables from the LAS File Data
   *     Structure to the New LAS File Data Structure
   * @param   stOld = LAS File Data Structure
   * @param   stNew = LAS File Data Structure
   * @return  stNew = LAS File Data Structure
   */

  public static lasFileDataStruct copy( lasFileDataStruct stOld,
                                        lasFileDataStruct stNew )
  {
    int i,j;

    if ((stOld != null) && (stNew != null))
    {
      stNew.iSource    = stOld.iSource;

      // -- Required Parameters

      stNew.sPDAT      = new String( stOld.sPDAT ); // Permanent Data
      stNew.dAPD       = stOld.dAPD;                // Above Permanent Data
      stNew.sDREF      = new String (stOld.sDREF ); // Depth Reference (KB,DF,CB)
      stNew.dElevation = stOld.dElevation;     // "Elevation of Depth Reference"

      // -- Required parameters for AEUB compliance

      stNew.dTDD       = stOld.dTDD;  // Drillers Depth
      stNew.dTLD       = stOld.dTLD;  // Loggers Depth

      stNew.dCSGL      = stOld.dCSGL; // Casing Bottom Logger
      stNew.dCSGD      = stOld.dCSGD; // Casing Bottom Driller
      stNew.dCSGS      = stOld.dCSGS; // Casing Size
      stNew.dCSGW      = stOld.dCSGW; // Casing Weight
      stNew.dBS        = stOld.dBS;   // Bit Size

      stNew.sMUD       = new String(stOld.sMUD);  // Mud type
      stNew.sMUDS      = new String(stOld.sMUDS); // Mud Source
      stNew.dMUDD      = stOld.dMUDD; // Mud Density
      stNew.dMUDV      = stOld.dMUDV; // Mud Viscosity (Funnel)

      stNew.dFL        = stOld.dFL;   // Fluid Loss
      stNew.dPH        = stOld.dPH;   // PH

      stNew.dRM        = stOld.dRM;   // Resistivity of Mud
      stNew.dRMT       = stOld.dRMT;  // Temperature of Mud
      stNew.dRMF       = stOld.dRMF;  // Resistivity of Mud Filtrate
      stNew.dRMFT      = stOld.dRMFT; // Temperature of Mud Filtrate
      stNew.dRMC       = stOld.dRMC;  // Resistivity of Mud Cake
      stNew.dRMCT      = stOld.dRMCT; // Temperature of Mud Cake
      stNew.dTMAX      = stOld.dTMAX; // Maximum Recorded Temp.

      stNew.sTIMC      = new String(stOld.sTIMC); // Date/Time Circulation Stopped
      stNew.sTIML      = new String(stOld.sTIML); // Date/Time Logger Tagged Bottom
      stNew.sUNIT      = new String(stOld.sUNIT); // Logging Unit Number
      stNew.sBASE      = new String(stOld.sBASE); // Home Base of Logging Unit
      stNew.sENG       = new String(stOld.sENG);  // Recording Engineer
      stNew.sWIT       = new String(stOld.sWIT);  // Witnessed By

      // .. Units for Required parameters for AEUB compliance

      stNew.sCSGL      = new String(stOld.sCSGL); // Casing Bottom Logger
      stNew.sCSGD      = new String(stOld.sCSGD); // Casing Bottom Driller
      stNew.sCSGS      = new String(stOld.sCSGS); // Casing Size
      stNew.sCSGW      = new String(stOld.sCSGW); // Casing Weight
      stNew.sBS        = new String(stOld.sBS); // Bit Size
      stNew.sMUDD      = new String(stOld.sMUDD); // Mud Density
      stNew.sMUDV      = new String(stOld.sMUDV); // Mud Viscosity (Funnel)
      stNew.sFL        = new String(stOld.sFL); // Fluid Loss
      stNew.sRM        = new String(stOld.sRM); // Resistivity of Mud
      stNew.sRMT       = new String(stOld.sRMT); // Temperature of Mud
      stNew.sRMF       = new String(stOld.sRMF); //  Rest. of Mud Filtrate
      stNew.sRMFT      = new String(stOld.sRMFT); // Temp. of Mud Filtrate
      stNew.sRMC       = new String(stOld.sRMC); // Rest. of Mud Cake
      stNew.sRMCT      = new String(stOld.sRMCT); // Temp. of Mud Cake
      stNew.sTMAX      = new String(stOld.sTMAX); // Max. Recorded Temp.

      // Unknown Curve Mnemonics

      stNew.sUnknown = new String[4][2];
      for (i=0; i<4; i++)
      {
		for (j=0; j<2; j++)
		{
		  stNew.sUnknown[i][j] = new String( stOld.sUnknown[i][j] );
		}
	  }

      // LAS 3 File Parameters

      stNew.iParamRows = stOld.iParamRows;    // Total number of rows
      stNew.iParamCols = stOld.iParamCols;    // Total number of columns
      stNew.sParams    = new String[stNew.iParamRows][stNew.iParamCols];

      for (i=0; i<stNew.iParamRows; i++)
      {
        for (j=0; j<stNew.iParamCols; j++)
        {
          // Array holding the Parameter Definitions
          stNew.sParams[i][j] = new String( stOld.sParams[i][j] );
        }
      }

      // Unknown Curve Mnemonics

      stNew.sUnknown = new String[4][2];
      for (i=0; i<4; i++)
      {
		for (j=0; j<2; j++)
		{
		  stNew.sUnknown[i][j] = new String( stOld.sUnknown[i][j] );
		}
	  }
    }

    return (stNew);
  }

  /** Method removeNull()
   * <p> This method will copy the LAS Data from one file to another.
   * @param   stOld = LAS File Data Structure
   * @return  stNew = LAS File Data Structure
   */

  public static lasFileDataStruct removeNull(lasFileDataStruct stOld)
  {
    int i,j;
    int iCount = 0;
    lasFileDataStruct stNew = null;

    if (stOld != null)
    {
      stNew            = new lasFileDataStruct();

      stNew.iSource    = stOld.iSource;

      stNew.sKID       = new String(stOld.sKID); // Primary Key for the KGS Well
      stNew.sKEY       = new String(stOld.sKEY); // Primary Key created by user
      stNew.iType      = stOld.iType;            // Type of Data

      stNew.sAPI       = new String(stOld.sAPI);  // API-Number of Well
      stNew.sName      = new String(stOld.sName); // Well Name

      // Other Fields not really displayed

      stNew.state      = new String(stOld.state);    // State Name
      stNew.sCounty    = new String(stOld.sCounty); // County Name

      // Well Location Information

      stNew.dLatitude  = stOld.dLatitude;  // Latitude of Well
      stNew.dLongitude = stOld.dLongitude; // Longitude of Well

      // Well Parameter Information

      stNew.dKB        = stOld.dKB; // Kelly Bushing of Well
      stNew.dGL        = stOld.dGL; // Ground Level of Well
      stNew.dTD        = stOld.dTD; // Total Depth of Well

      // Well Status

      stNew.status     = new String(stOld.status); // Status of Well

      // LAS File Information

      stNew.sReadMethod = new String(stOld.sReadMethod);  // File Read Method
      stNew.sDirectory  = new String(stOld.sDirectory); // Directory Path
      stNew.sFilename   = new String(stOld.sFilename);  // File name of LAS File
      stNew.sVersion    = new String(stOld.sVersion);   // LAS Version Number

      stNew.dNull       = stOld.dNull;      // Null Value of Data
      stNew.depthStart  = stOld.depthStart; // Start Depth of LAS Data
      stNew.depthEnd    = stOld.depthEnd;   // Ending Depth of LAS Data
      stNew.depthStep   = stOld.depthStep;  // Depth Step of LAS DAta

      stNew.dTimeStart  = stOld.dTimeStart; // Start Time of LAS Data
      stNew.dTimeEnd    = stOld.dTimeEnd;   // Ending Time of LAS Data

      stNew.iProprietary = stOld.iProprietary; // Proprietary Data Identfier

      // -- Required Parameters

      stNew.sPDAT      = new String( stOld.sPDAT ); // Permanent Data
      stNew.dAPD       = stOld.dAPD;                // Above Permanent Data
      stNew.sDREF      = new String (stOld.sDREF ); // Depth Reference (KB,DF,CB)
      stNew.dElevation = stOld.dElevation;     // "Elevation of Depth Reference"

      // -- Required parameters for AEUB compliance

      stNew.dTDD       = stOld.dTDD;  // Drillers Depth
      stNew.dTLD       = stOld.dTLD;  // Loggers Depth

      stNew.dCSGL      = stOld.dCSGL; // Casing Bottom Logger
      stNew.dCSGD      = stOld.dCSGD; // Casing Bottom Driller
      stNew.dCSGS      = stOld.dCSGS; // Casing Size
      stNew.dCSGW      = stOld.dCSGW; // Casing Weight
      stNew.dBS        = stOld.dBS;   // Bit Size

      stNew.sMUD       = new String(stOld.sMUD);  // Mud type
      stNew.sMUDS      = new String(stOld.sMUDS); // Mud Source
      stNew.dMUDD      = stOld.dMUDD; // Mud Density
      stNew.dMUDV      = stOld.dMUDV; // Mud Viscosity (Funnel)

      stNew.dFL        = stOld.dFL;   // Fluid Loss
      stNew.dPH        = stOld.dPH;   // PH

      stNew.dRM        = stOld.dRM;   // Resistivity of Mud
      stNew.dRMT       = stOld.dRMT;  // Temperature of Mud
      stNew.dRMF       = stOld.dRMF;  // Resistivity of Mud Filtrate
      stNew.dRMFT      = stOld.dRMFT; // Temperature of Mud Filtrate
      stNew.dRMC       = stOld.dRMC;  // Resistivity of Mud Cake
      stNew.dRMCT      = stOld.dRMCT; // Temperature of Mud Cake
      stNew.dTMAX      = stOld.dTMAX; // Maximum Recorded Temp.

      stNew.sTIMC      = new String(stOld.sTIMC); // Date/Time Circulation Stopped
      stNew.sTIML      = new String(stOld.sTIML); // Date/Time Logger Tagged Bottom
      stNew.sUNIT      = new String(stOld.sUNIT); // Logging Unit Number
      stNew.sBASE      = new String(stOld.sBASE); // Home Base of Logging Unit
      stNew.sENG       = new String(stOld.sENG);  // Recording Engineer
      stNew.sWIT       = new String(stOld.sWIT);  // Witnessed By

      // .. Units for Required parameters for AEUB compliance

      stNew.sCSGL      = new String(stOld.sCSGL); // Casing Bottom Logger
      stNew.sCSGD      = new String(stOld.sCSGD); // Casing Bottom Driller
      stNew.sCSGS      = new String(stOld.sCSGS); // Casing Size
      stNew.sCSGW      = new String(stOld.sCSGW); // Casing Weight
      stNew.sBS        = new String(stOld.sBS); // Bit Size
      stNew.sMUDD      = new String(stOld.sMUDD); // Mud Density
      stNew.sMUDV      = new String(stOld.sMUDV); // Mud Viscosity (Funnel)
      stNew.sFL        = new String(stOld.sFL); // Fluid Loss
      stNew.sRM        = new String(stOld.sRM); // Resistivity of Mud
      stNew.sRMT       = new String(stOld.sRMT); // Temperature of Mud
      stNew.sRMF       = new String(stOld.sRMF); //  Rest. of Mud Filtrate
      stNew.sRMFT      = new String(stOld.sRMFT); // Temp. of Mud Filtrate
      stNew.sRMC       = new String(stOld.sRMC); // Rest. of Mud Cake
      stNew.sRMCT      = new String(stOld.sRMCT); // Temp. of Mud Cake
      stNew.sTMAX      = new String(stOld.sTMAX); // Max. Recorded Temp.

      // LAS 3 File Parameters

      stNew.iParamRows = stOld.iParamRows;    // Total number of rows
      stNew.iParamCols = stOld.iParamCols;    // Total number of columns
      stNew.sParams    = new String[stNew.iParamRows][stNew.iParamCols];

      for (i=0; i<stNew.iParamRows; i++)
      {
        for (j=0; j<stNew.iParamCols; j++)
        {
          // Array holding the Parameter Definitions
          stNew.sParams[i][j] = new String( stOld.sParams[i][j] );
        }
      }

      stNew.iLogs = stOld.iLogs;  // Total number of LAS3 Data Structures
      if (stOld.iLogs > 0)
      {
        stNew.stLAS3 = new las3Struct[stOld.iLogs];
        for (i=0; i<stOld.iLogs; i++)
        {
          stNew.stLAS3[i] = las3.las3Utility.copyWOData( stOld.stLAS3[i] );
        }
      }

      // Unknown Curve Mnemonics

      stNew.sUnknown = new String[4][2];
      for (i=0; i<4; i++)
      {
		for (j=0; j<2; j++)
		{
		  stNew.sUnknown[i][j] = new String( stOld.sUnknown[i][j] );
		}
	  }

      // LAS File Curve Information

      stNew.iColorlithDefault = stOld.iColorlithDefault; // Default colorlith

      stNew.iCAL1     = stOld.iCAL1;     // Caliper 1 Log Values
      stNew.iCAL2     = stOld.iCAL2;     // Caliper 2 Log Values
      stNew.iCAL3     = stOld.iCAL3;     // Caliper 3 Log Values
      stNew.iCAL4     = stOld.iCAL4;     // Caliper 4 Log Values
      stNew.iCAL5     = stOld.iCAL5;     // Caliper 5 Log Values
      stNew.iCAL6     = stOld.iCAL6;     // Caliper 6 Log Values

      stNew.iAZIC1    = stOld.iAZIC1;    // Azimuth degrees for pad 1 Log Values

      stNew.iRows     = stOld.iRows;    // Number of Rows
      stNew.depths    = new double[stNew.iRows]; // Array of Depth Data Values

      stNew.dCAL1     = new double[stNew.iRows]; // Array of Caliper 1 Log Values
      stNew.dCAL2     = new double[stNew.iRows]; // Array of Caliper 2 Log Values
      stNew.dCAL3     = new double[stNew.iRows]; // Array of Caliper 3 Log Values
      stNew.dCAL4     = new double[stNew.iRows]; // Array of Caliper 4 Log Values
      stNew.dCAL5     = new double[stNew.iRows]; // Array of Caliper 5 Log Values
      stNew.dCAL6     = new double[stNew.iRows]; // Array of Caliper 6 Log Values

      stNew.dAZIC1    = new double[stNew.iRows]; // Array of Azimuth degrees for pad 1 Log Values

      for (i=0; i<stOld.iRows; i++)
      {
		if ((stOld.dCAL1[i] != stOld.dNull) && (stOld.dAZIC1[i] != stOld.dNull))
		{
          stNew.depths[iCount] = stOld.depths[i]; // Array of Depth Data Values

          stNew.dCAL1[iCount]  = stOld.dCAL1[i];  // Array of Caliper Log Values
          stNew.dCAL2[iCount]  = stOld.dCAL2[i];  // Array of Caliper Log Values
          stNew.dCAL3[iCount]  = stOld.dCAL3[i];  // Array of Caliper Log Values
          stNew.dCAL4[iCount]  = stOld.dCAL4[i];  // Array of Caliper Log Values
          stNew.dCAL5[iCount]  = stOld.dCAL5[i];  // Array of Caliper Log Values
          stNew.dCAL6[iCount]  = stOld.dCAL6[i];  // Array of Caliper Log Values

          stNew.dAZIC1[iCount] = stOld.dAZIC1[i]; // Array of Azimuth degrees for pad 1 Log Values
          iCount++;
		}
      }

      stNew.iRows = iCount;

      stOld.delete();
      stOld = null;
    }

    return (stNew);
  }

  /** Method filterBy()
   * <p> This method will copy the LAS Data from one file to another.
   * @param   stOld = LAS File Data Structure
   * @param   dIncr = Increment by
   * @return  stNew = LAS File Data Structure
   */

  public static lasFileDataStruct filterBy(lasFileDataStruct stOld, double dIncr)
  {
    int    i,j;
    int    iCount = 0;
    int    iStart = 0;
    double depth  = 0.0;
    lasFileDataStruct stNew = null;

    if (stOld != null)
    {
      stNew            = new lasFileDataStruct();

      stNew.iSource    = stOld.iSource;

      stNew.sKID       = new String(stOld.sKID); // Primary Key for the KGS Well
      stNew.sKEY       = new String(stOld.sKEY); // Primary Key created by user
      stNew.iType      = stOld.iType;            // Type of Data

      stNew.sAPI       = new String(stOld.sAPI);  // API-Number of Well
      stNew.sName      = new String(stOld.sName); // Well Name

      // Other Fields not really displayed

      stNew.state      = new String(stOld.state);    // State Name
      stNew.sCounty    = new String(stOld.sCounty); // County Name

      // Well Location Information

      stNew.dLatitude  = stOld.dLatitude;  // Latitude of Well
      stNew.dLongitude = stOld.dLongitude; // Longitude of Well

      // Well Parameter Information

      stNew.dKB        = stOld.dKB; // Kelly Bushing of Well
      stNew.dGL        = stOld.dGL; // Ground Level of Well
      stNew.dTD        = stOld.dTD; // Total Depth of Well

      // Well Status

      stNew.status     = new String(stOld.status); // Status of Well

      // LAS File Information

      stNew.sReadMethod = new String(stOld.sReadMethod);  // File Read Method
      stNew.sDirectory  = new String(stOld.sDirectory); // Directory Path
      stNew.sFilename   = new String(stOld.sFilename);  // File name of LAS File
      stNew.sVersion    = new String(stOld.sVersion);   // LAS Version Number

      stNew.dNull       = stOld.dNull;      // Null Value of Data
      stNew.depthStart  = stOld.depthStart; // Start Depth of LAS Data
      stNew.depthEnd    = stOld.depthEnd;   // Ending Depth of LAS Data
      stNew.depthStep   = stOld.depthStep;  // Depth Step of LAS DAta

      stNew.dTimeStart  = stOld.dTimeStart; // Start Time of LAS Data
      stNew.dTimeEnd    = stOld.dTimeEnd;   // Ending Time of LAS Data

      stNew.iProprietary = stOld.iProprietary; // Proprietary Data Identfier

      // -- Required Parameters

      stNew.sPDAT      = new String( stOld.sPDAT ); // Permanent Data
      stNew.dAPD       = stOld.dAPD;                // Above Permanent Data
      stNew.sDREF      = new String (stOld.sDREF ); // Depth Reference (KB,DF,CB)
      stNew.dElevation = stOld.dElevation;     // "Elevation of Depth Reference"

      // -- Required parameters for AEUB compliance

      stNew.dTDD       = stOld.dTDD;  // Drillers Depth
      stNew.dTLD       = stOld.dTLD;  // Loggers Depth

      stNew.dCSGL      = stOld.dCSGL; // Casing Bottom Logger
      stNew.dCSGD      = stOld.dCSGD; // Casing Bottom Driller
      stNew.dCSGS      = stOld.dCSGS; // Casing Size
      stNew.dCSGW      = stOld.dCSGW; // Casing Weight
      stNew.dBS        = stOld.dBS;   // Bit Size

      stNew.sMUD       = new String(stOld.sMUD);  // Mud type
      stNew.sMUDS      = new String(stOld.sMUDS); // Mud Source
      stNew.dMUDD      = stOld.dMUDD; // Mud Density
      stNew.dMUDV      = stOld.dMUDV; // Mud Viscosity (Funnel)

      stNew.dFL        = stOld.dFL;   // Fluid Loss
      stNew.dPH        = stOld.dPH;   // PH

      stNew.dRM        = stOld.dRM;   // Resistivity of Mud
      stNew.dRMT       = stOld.dRMT;  // Temperature of Mud
      stNew.dRMF       = stOld.dRMF;  // Resistivity of Mud Filtrate
      stNew.dRMFT      = stOld.dRMFT; // Temperature of Mud Filtrate
      stNew.dRMC       = stOld.dRMC;  // Resistivity of Mud Cake
      stNew.dRMCT      = stOld.dRMCT; // Temperature of Mud Cake
      stNew.dTMAX      = stOld.dTMAX; // Maximum Recorded Temp.

      stNew.sTIMC      = new String(stOld.sTIMC); // Date/Time Circulation Stopped
      stNew.sTIML      = new String(stOld.sTIML); // Date/Time Logger Tagged Bottom
      stNew.sUNIT      = new String(stOld.sUNIT); // Logging Unit Number
      stNew.sBASE      = new String(stOld.sBASE); // Home Base of Logging Unit
      stNew.sENG       = new String(stOld.sENG);  // Recording Engineer
      stNew.sWIT       = new String(stOld.sWIT);  // Witnessed By

      // .. Units for Required parameters for AEUB compliance

      stNew.sCSGL      = new String(stOld.sCSGL); // Casing Bottom Logger
      stNew.sCSGD      = new String(stOld.sCSGD); // Casing Bottom Driller
      stNew.sCSGS      = new String(stOld.sCSGS); // Casing Size
      stNew.sCSGW      = new String(stOld.sCSGW); // Casing Weight
      stNew.sBS        = new String(stOld.sBS); // Bit Size
      stNew.sMUDD      = new String(stOld.sMUDD); // Mud Density
      stNew.sMUDV      = new String(stOld.sMUDV); // Mud Viscosity (Funnel)
      stNew.sFL        = new String(stOld.sFL); // Fluid Loss
      stNew.sRM        = new String(stOld.sRM); // Resistivity of Mud
      stNew.sRMT       = new String(stOld.sRMT); // Temperature of Mud
      stNew.sRMF       = new String(stOld.sRMF); //  Rest. of Mud Filtrate
      stNew.sRMFT      = new String(stOld.sRMFT); // Temp. of Mud Filtrate
      stNew.sRMC       = new String(stOld.sRMC); // Rest. of Mud Cake
      stNew.sRMCT      = new String(stOld.sRMCT); // Temp. of Mud Cake
      stNew.sTMAX      = new String(stOld.sTMAX); // Max. Recorded Temp.

      // LAS 3 File Parameters

      stNew.iParamRows = stOld.iParamRows;    // Total number of rows
      stNew.iParamCols = stOld.iParamCols;    // Total number of columns
      stNew.sParams    = new String[stNew.iParamRows][stNew.iParamCols];

      for (i=0; i<stNew.iParamRows; i++)
      {
        for (j=0; j<stNew.iParamCols; j++)
        {
          // Array holding the Parameter Definitions
          stNew.sParams[i][j] = new String( stOld.sParams[i][j] );
        }
      }

      stNew.iLogs = stOld.iLogs;  // Total number of LAS3 Data Structures
      if (stOld.iLogs > 0)
      {
        stNew.stLAS3 = new las3Struct[stOld.iLogs];
        for (i=0; i<stOld.iLogs; i++)
        {
          stNew.stLAS3[i] = las3.las3Utility.copyWOData( stOld.stLAS3[i] );
        }
      }

      // Unknown Curve Mnemonics

      stNew.sUnknown = new String[4][2];
      for (i=0; i<4; i++)
      {
		for (j=0; j<2; j++)
		{
		  stNew.sUnknown[i][j] = new String( stOld.sUnknown[i][j] );
		}
	  }

      // LAS File Curve Information

      stNew.iColorlithDefault = stOld.iColorlithDefault; // Default colorlith

      stNew.iCAL1     = stOld.iCAL1;     // Caliper 1 Log Values
      stNew.iCAL2     = stOld.iCAL2;     // Caliper 2 Log Values
      stNew.iCAL3     = stOld.iCAL3;     // Caliper 3 Log Values
      stNew.iCAL4     = stOld.iCAL4;     // Caliper 4 Log Values
      stNew.iCAL5     = stOld.iCAL5;     // Caliper 5 Log Values
      stNew.iCAL6     = stOld.iCAL6;     // Caliper 6 Log Values

      stNew.iAZIC1    = stOld.iAZIC1;    // Azimuth degrees for pad 1 Log Values

      stNew.iRows     = stOld.iRows;    // Number of Rows
      stNew.depths    = new double[stNew.iRows]; // Array of Depth Data Values

      stNew.dCAL1     = new double[stNew.iRows]; // Array of Caliper 1 Log Values
      stNew.dCAL2     = new double[stNew.iRows]; // Array of Caliper 2 Log Values
      stNew.dCAL3     = new double[stNew.iRows]; // Array of Caliper 3 Log Values
      stNew.dCAL4     = new double[stNew.iRows]; // Array of Caliper 4 Log Values
      stNew.dCAL5     = new double[stNew.iRows]; // Array of Caliper 5 Log Values
      stNew.dCAL6     = new double[stNew.iRows]; // Array of Caliper 6 Log Values

      stNew.dAZIC1    = new double[stNew.iRows]; // Array of Azimuth degrees for pad 1 Log Values

      for (i=0; i<stOld.iRows; i++)
      {
		if ((stOld.dCAL1[i] != stOld.dNull) && (stOld.dAZIC1[i] != stOld.dNull))
		{
  		  if (iStart == 0)
  		  {
			depth = stOld.depths[i];
			iStart = 1;
		  }

		  if (stOld.depths[i] == depth)
		  {
            stNew.depths[iCount] = stOld.depths[i]; // Array of Depth Data Values

            stNew.dCAL1[iCount]  = stOld.dCAL1[i];  // Array of Caliper Log Values
            stNew.dCAL2[iCount]  = stOld.dCAL2[i];  // Array of Caliper Log Values
            stNew.dCAL3[iCount]  = stOld.dCAL3[i];  // Array of Caliper Log Values
            stNew.dCAL4[iCount]  = stOld.dCAL4[i];  // Array of Caliper Log Values
            stNew.dCAL5[iCount]  = stOld.dCAL5[i];  // Array of Caliper Log Values
            stNew.dCAL6[iCount]  = stOld.dCAL6[i];  // Array of Caliper Log Values

            stNew.dAZIC1[iCount] = stOld.dAZIC1[i]; // Array of Azimuth degrees for pad 1 Log Values
            iCount++;

            depth = depth + dIncr;
		  }
		}
      }

      stNew.iRows = iCount;
    }

    return (stNew);
  }

  /** Method copy()
   * <p> This method will copy the LAS Data from one file to another.
   * @param   stOld = LAS File Data Structure
   * @return  stNew = LAS File Data Structure
   */

  public static lasFileDataStruct copy(lasFileDataStruct stOld)
  {
    int i,j;
    lasFileDataStruct stNew = null;

    if (stOld != null)
    {
      stNew            = new lasFileDataStruct();

      stNew.iSource    = stOld.iSource;

      stNew.sKID       = new String(stOld.sKID); // Primary Key for the KGS Well
      stNew.sKEY       = new String(stOld.sKEY); // Primary Key created by user
      stNew.iType      = stOld.iType;            // Type of Data

      stNew.sAPI       = new String(stOld.sAPI);  // API-Number of Well
      stNew.sName      = new String(stOld.sName); // Well Name

      // Other Fields not really displayed

      stNew.state      = new String(stOld.state);    // State Name
      stNew.sCounty    = new String(stOld.sCounty); // County Name

      // Well Location Information

      stNew.dLatitude  = stOld.dLatitude;  // Latitude of Well
      stNew.dLongitude = stOld.dLongitude; // Longitude of Well

      // Well Parameter Information

      stNew.dKB        = stOld.dKB; // Kelly Bushing of Well
      stNew.dGL        = stOld.dGL; // Ground Level of Well
      stNew.dTD        = stOld.dTD; // Total Depth of Well

      // Well Status

      stNew.status     = new String(stOld.status); // Status of Well

      // LAS File Information

      stNew.sReadMethod = new String(stOld.sReadMethod);  // File Read Method
      stNew.sDirectory  = new String(stOld.sDirectory); // Directory Path
      stNew.sFilename   = new String(stOld.sFilename);  // File name of LAS File
      stNew.sVersion    = new String(stOld.sVersion);   // LAS Version Number

      stNew.dNull       = stOld.dNull;      // Null Value of Data
      stNew.depthStart  = stOld.depthStart; // Start Depth of LAS Data
      stNew.depthEnd    = stOld.depthEnd;   // Ending Depth of LAS Data
      stNew.depthStep   = stOld.depthStep;  // Depth Step of LAS DAta

      stNew.dTimeStart  = stOld.dTimeStart; // Start Time of LAS Data
      stNew.dTimeEnd    = stOld.dTimeEnd;   // Ending Time of LAS Data

      stNew.iProprietary = stOld.iProprietary; // Proprietary Data Identfier

      // -- Required Parameters

      stNew.sPDAT      = new String( stOld.sPDAT ); // Permanent Data
      stNew.dAPD       = stOld.dAPD;                // Above Permanent Data
      stNew.sDREF      = new String (stOld.sDREF ); // Depth Reference (KB,DF,CB)
      stNew.dElevation = stOld.dElevation;     // "Elevation of Depth Reference"

      // -- Required parameters for AEUB compliance

      stNew.dTDD       = stOld.dTDD;  // Drillers Depth
      stNew.dTLD       = stOld.dTLD;  // Loggers Depth

      stNew.dCSGL      = stOld.dCSGL; // Casing Bottom Logger
      stNew.dCSGD      = stOld.dCSGD; // Casing Bottom Driller
      stNew.dCSGS      = stOld.dCSGS; // Casing Size
      stNew.dCSGW      = stOld.dCSGW; // Casing Weight
      stNew.dBS        = stOld.dBS;   // Bit Size

      stNew.sMUD       = new String(stOld.sMUD);  // Mud type
      stNew.sMUDS      = new String(stOld.sMUDS); // Mud Source
      stNew.dMUDD      = stOld.dMUDD; // Mud Density
      stNew.dMUDV      = stOld.dMUDV; // Mud Viscosity (Funnel)

      stNew.dFL        = stOld.dFL;   // Fluid Loss
      stNew.dPH        = stOld.dPH;   // PH

      stNew.dRM        = stOld.dRM;   // Resistivity of Mud
      stNew.dRMT       = stOld.dRMT;  // Temperature of Mud
      stNew.dRMF       = stOld.dRMF;  // Resistivity of Mud Filtrate
      stNew.dRMFT      = stOld.dRMFT; // Temperature of Mud Filtrate
      stNew.dRMC       = stOld.dRMC;  // Resistivity of Mud Cake
      stNew.dRMCT      = stOld.dRMCT; // Temperature of Mud Cake
      stNew.dTMAX      = stOld.dTMAX; // Maximum Recorded Temp.

      stNew.sTIMC      = new String(stOld.sTIMC); // Date/Time Circulation Stopped
      stNew.sTIML      = new String(stOld.sTIML); // Date/Time Logger Tagged Bottom
      stNew.sUNIT      = new String(stOld.sUNIT); // Logging Unit Number
      stNew.sBASE      = new String(stOld.sBASE); // Home Base of Logging Unit
      stNew.sENG       = new String(stOld.sENG);  // Recording Engineer
      stNew.sWIT       = new String(stOld.sWIT);  // Witnessed By

      // .. Units for Required parameters for AEUB compliance

      stNew.sCSGL      = new String(stOld.sCSGL); // Casing Bottom Logger
      stNew.sCSGD      = new String(stOld.sCSGD); // Casing Bottom Driller
      stNew.sCSGS      = new String(stOld.sCSGS); // Casing Size
      stNew.sCSGW      = new String(stOld.sCSGW); // Casing Weight
      stNew.sBS        = new String(stOld.sBS); // Bit Size
      stNew.sMUDD      = new String(stOld.sMUDD); // Mud Density
      stNew.sMUDV      = new String(stOld.sMUDV); // Mud Viscosity (Funnel)
      stNew.sFL        = new String(stOld.sFL); // Fluid Loss
      stNew.sRM        = new String(stOld.sRM); // Resistivity of Mud
      stNew.sRMT       = new String(stOld.sRMT); // Temperature of Mud
      stNew.sRMF       = new String(stOld.sRMF); //  Rest. of Mud Filtrate
      stNew.sRMFT      = new String(stOld.sRMFT); // Temp. of Mud Filtrate
      stNew.sRMC       = new String(stOld.sRMC); // Rest. of Mud Cake
      stNew.sRMCT      = new String(stOld.sRMCT); // Temp. of Mud Cake
      stNew.sTMAX      = new String(stOld.sTMAX); // Max. Recorded Temp.

      // LAS 3 File Parameters

      stNew.iParamRows = stOld.iParamRows;    // Total number of rows
      stNew.iParamCols = stOld.iParamCols;    // Total number of columns
      stNew.sParams    = new String[stNew.iParamRows][stNew.iParamCols];

      for (i=0; i<stNew.iParamRows; i++)
      {
        for (j=0; j<stNew.iParamCols; j++)
        {
          // Array holding the Parameter Definitions
          stNew.sParams[i][j] = new String( stOld.sParams[i][j] );
        }
      }

      stNew.iLogs = stOld.iLogs;  // Total number of LAS3 Data Structures
      if (stOld.iLogs > 0)
      {
        stNew.stLAS3 = new las3Struct[stOld.iLogs];
        for (i=0; i<stOld.iLogs; i++)
        {
          stNew.stLAS3[i] = las3.las3Utility.copyWOData( stOld.stLAS3[i] );
        }
      }

      // Unknown Curve Mnemonics

      stNew.sUnknown = new String[4][2];
      for (i=0; i<4; i++)
      {
		for (j=0; j<2; j++)
		{
		  stNew.sUnknown[i][j] = new String( stOld.sUnknown[i][j] );
		}
	  }

      // LAS File Curve Information

      stNew.iColorlithDefault = stOld.iColorlithDefault; // Default colorlith

      stNew.iCAL1     = stOld.iCAL1;     // Caliper 1 Log Values
      stNew.iCAL2     = stOld.iCAL2;     // Caliper 2 Log Values
      stNew.iCAL3     = stOld.iCAL3;     // Caliper 3 Log Values
      stNew.iCAL4     = stOld.iCAL4;     // Caliper 4 Log Values
      stNew.iCAL5     = stOld.iCAL5;     // Caliper 5 Log Values
      stNew.iCAL6     = stOld.iCAL6;     // Caliper 6 Log Values

      stNew.iAZIC1    = stOld.iAZIC1;    // Azimuth degrees for pad 1 Log Values

      stNew.iRows     = stOld.iRows;    // Number of Rows
      stNew.depths    = new double[stNew.iRows]; // Array of Depth Data Values

      stNew.dCAL1     = new double[stNew.iRows]; // Array of Caliper 1 Log Values
      stNew.dCAL2     = new double[stNew.iRows]; // Array of Caliper 2 Log Values
      stNew.dCAL3     = new double[stNew.iRows]; // Array of Caliper 3 Log Values
      stNew.dCAL4     = new double[stNew.iRows]; // Array of Caliper 4 Log Values
      stNew.dCAL5     = new double[stNew.iRows]; // Array of Caliper 5 Log Values
      stNew.dCAL6     = new double[stNew.iRows]; // Array of Caliper 6 Log Values

      stNew.dAZIC1    = new double[stNew.iRows]; // Array of Azimuth degrees for pad 1 Log Values

      for (i=0; i<stOld.iRows; i++)
      {
        stNew.depths[i]    = stOld.depths[i];    // Array of Depth Data Values

        stNew.dCAL1[i]     = stOld.dCAL1[i];     // Array of Caliper Log Values
        stNew.dCAL2[i]     = stOld.dCAL2[i];     // Array of Caliper Log Values
        stNew.dCAL3[i]     = stOld.dCAL3[i];     // Array of Caliper Log Values
        stNew.dCAL4[i]     = stOld.dCAL4[i];     // Array of Caliper Log Values
        stNew.dCAL5[i]     = stOld.dCAL5[i];     // Array of Caliper Log Values
        stNew.dCAL6[i]     = stOld.dCAL6[i];     // Array of Caliper Log Values

        stNew.dAZIC1[i]    = stOld.dAZIC1[i];    // Array of Azimuth degrees for pad 1 Log Values
      }
    }

    return (stNew);
  }

  /** Method transfer()
   *  <p> This method will transfer the contents of the data structure to the new and
   *      delete the old structure.
   * @param   stOld = LAS File Data Structure
   * @return  stNew = LAS File Data Structure
   */

  public static lasFileDataStruct transfer(lasFileDataStruct stOld)
  {
    lasFileDataStruct stNew = null;

    if (stOld != null)
    {
	  stNew = copy( stOld );

	  stOld.delete();
	  stOld = null;
	}

    return (stNew);
  }

  /** Method findCurves()
   * <p> This method will identify the color litholgy curves in the LAS File.
   * @param  stCurves = The LAS Curve Data
   * @param  stC = The LAS File Data Structure
   * @return stC = The LAS File Data Structure
   */

  public static lasFileDataStruct findCurves( cmnLASCurveListStruct stCurves,
                                              lasFileDataStruct stC )
  {
    if (stCurves != null)
    {
      for (int i=0; i<stCurves.iCount; i++)
      {
		if (stCurves.stItem[i] != null)
		{
          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._CAL1][0]))
          {
            if (stC.iCAL1 == -1)
              stC.iCAL1 = stCurves.stItem[i].iCurveNumber;
          }

          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._CAL2][0]))
          {
            if (stC.iCAL2 == -1)
              stC.iCAL2 = stCurves.stItem[i].iCurveNumber;
          }

          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._CAL3][0]))
          {
            if (stC.iCAL3 == -1)
              stC.iCAL3 = stCurves.stItem[i].iCurveNumber;
          }

          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._CAL4][0]))
          {
            if (stC.iCAL4 == -1)
              stC.iCAL4 = stCurves.stItem[i].iCurveNumber;
          }

          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._CAL5][0]))
          {
            if (stC.iCAL5 == -1)
              stC.iCAL5 = stCurves.stItem[i].iCurveNumber;
          }

          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._CAL6][0]))
          {
            if (stC.iCAL6 == -1)
              stC.iCAL6 = stCurves.stItem[i].iCurveNumber;
          }

          if (stCurves.stItem[i].sToolKID.equals(
            las.lasStandardTools.LAS_TOOLS[las.lasStandardTools._AZIC1][0]))
          {
            if (stC.iAZIC1 == -1)
              stC.iAZIC1 = stCurves.stItem[i].iCurveNumber;
          }
	    }
      }
    }

    return (stC);
  }


  /** Method copyHeader()
   * <p> This method will copy the Header & Parameters Data to the data structure
   * @param  stOld = LAS File Data Structure
   * @param  stNew = LAS File Data Structure
   * @return stNew = LAS File Data Structure
   */

  public static lasFileDataStruct copyHeader( lasFileDataStruct stOld,
                                              lasFileDataStruct stNew )
  {
	int i,j;

	if ((stOld != null) && (stNew != null))
	{
      stNew.sKID       = new String(stOld.sKID); // Primary Key for the KGS Well
      stNew.sKEY       = new String(stOld.sKEY); // Primary Key created by user
      stNew.iType      = stOld.iType;            // Type of Data

      stNew.sAPI       = new String(stOld.sAPI);  // API-Number of Well
      stNew.sName      = new String(stOld.sName); // Well Name

      // Other Fields not really displayed

      stNew.state      = new String(stOld.state);    // State Name
      stNew.sCounty    = new String(stOld.sCounty); // County Name

      // Well Location Information

      stNew.dLatitude  = stOld.dLatitude;  // Latitude of Well
      stNew.dLongitude = stOld.dLongitude; // Longitude of Well

      // Well Parameter Information

      stNew.dKB        = stOld.dKB; // Kelly Bushing of Well
      stNew.dGL        = stOld.dGL; // Ground Level of Well
      stNew.dTD        = stOld.dTD; // Total Depth of Well

      // Well Status

      stNew.status     = new String(stOld.status); // Status of Well

      // LAS File Information

      stNew.sReadMethod = new String(stOld.sReadMethod);  // File Read Method
      stNew.sDirectory  = new String(stOld.sDirectory); // Directory Path
      stNew.sFilename   = new String(stOld.sFilename);  // File name of LAS File
      stNew.sVersion    = new String(stOld.sVersion);   // LAS Version Number

      stNew.dNull       = stOld.dNull;      // Null Value of Data
      stNew.depthStart  = stOld.depthStart; // Start Depth of LAS Data
      stNew.depthEnd    = stOld.depthEnd;   // Ending Depth of LAS Data
      stNew.depthStep   = stOld.depthStep;  // Depth Step of LAS DAta

      stNew.iProprietary = stOld.iProprietary; // Proprietary Data Identfier

      // -- Required Parameters

      stNew.sPDAT      = new String( stOld.sPDAT ); // Permanent Data
      stNew.dAPD       = stOld.dAPD;                // Above Permanent Data
      stNew.sDREF      = new String (stOld.sDREF ); // Depth Reference (KB,DF,CB)
      stNew.dElevation = stOld.dElevation;     // "Elevation of Depth Reference"

      // -- Required parameters for AEUB compliance

      stNew.dTDD       = stOld.dTDD;  // Drillers Depth
      stNew.dTLD       = stOld.dTLD;  // Loggers Depth

      stNew.dCSGL      = stOld.dCSGL; // Casing Bottom Logger
      stNew.dCSGD      = stOld.dCSGD; // Casing Bottom Driller
      stNew.dCSGS      = stOld.dCSGS; // Casing Size
      stNew.dCSGW      = stOld.dCSGW; // Casing Weight
      stNew.dBS        = stOld.dBS;   // Bit Size

      stNew.sMUD       = new String(stOld.sMUD);  // Mud type
      stNew.sMUDS      = new String(stOld.sMUDS); // Mud Source
      stNew.dMUDD      = stOld.dMUDD; // Mud Density
      stNew.dMUDV      = stOld.dMUDV; // Mud Viscosity (Funnel)

      stNew.dFL        = stOld.dFL;   // Fluid Loss
      stNew.dPH        = stOld.dPH;   // PH

      stNew.dRM        = stOld.dRM;   // Resistivity of Mud
      stNew.dRMT       = stOld.dRMT;  // Temperature of Mud
      stNew.dRMF       = stOld.dRMF;  // Resistivity of Mud Filtrate
      stNew.dRMFT      = stOld.dRMFT; // Temperature of Mud Filtrate
      stNew.dRMC       = stOld.dRMC;  // Resistivity of Mud Cake
      stNew.dRMCT      = stOld.dRMCT; // Temperature of Mud Cake
      stNew.dTMAX      = stOld.dTMAX; // Maximum Recorded Temp.

      stNew.sTIMC      = new String(stOld.sTIMC); // Date/Time Circulation Stopped
      stNew.sTIML      = new String(stOld.sTIML); // Date/Time Logger Tagged Bottom
      stNew.sUNIT      = new String(stOld.sUNIT); // Logging Unit Number
      stNew.sBASE      = new String(stOld.sBASE); // Home Base of Logging Unit
      stNew.sENG       = new String(stOld.sENG);  // Recording Engineer
      stNew.sWIT       = new String(stOld.sWIT);  // Witnessed By

      // .. Units for Required parameters for AEUB compliance

      stNew.sCSGL      = new String(stOld.sCSGL); // Casing Bottom Logger
      stNew.sCSGD      = new String(stOld.sCSGD); // Casing Bottom Driller
      stNew.sCSGS      = new String(stOld.sCSGS); // Casing Size
      stNew.sCSGW      = new String(stOld.sCSGW); // Casing Weight
      stNew.sBS        = new String(stOld.sBS); // Bit Size
      stNew.sMUDD      = new String(stOld.sMUDD); // Mud Density
      stNew.sMUDV      = new String(stOld.sMUDV); // Mud Viscosity (Funnel)
      stNew.sFL        = new String(stOld.sFL); // Fluid Loss
      stNew.sRM        = new String(stOld.sRM); // Resistivity of Mud
      stNew.sRMT       = new String(stOld.sRMT); // Temperature of Mud
      stNew.sRMF       = new String(stOld.sRMF); //  Rest. of Mud Filtrate
      stNew.sRMFT      = new String(stOld.sRMFT); // Temp. of Mud Filtrate
      stNew.sRMC       = new String(stOld.sRMC); // Rest. of Mud Cake
      stNew.sRMCT      = new String(stOld.sRMCT); // Temp. of Mud Cake
      stNew.sTMAX      = new String(stOld.sTMAX); // Max. Recorded Temp.

      // LAS 3 File Parameters

      stNew.iParamRows = stOld.iParamRows;    // Total number of rows
      stNew.iParamCols = stOld.iParamCols;    // Total number of columns
      stNew.sParams    = new String[stNew.iParamRows][stNew.iParamCols];

      for (i=0; i<stNew.iParamRows; i++)
      {
        for (j=0; j<stNew.iParamCols; j++)
        {
          // Array holding the Parameter Definitions
          stNew.sParams[i][j] = new String( stOld.sParams[i][j] );
        }
      }

      stNew.iLogs = stOld.iLogs;  // Total number of LAS3 Data Structures
      if (stOld.iLogs > 0)
      {
        stNew.stLAS3 = new las3Struct[stOld.iLogs];
        for (i=0; i<stOld.iLogs; i++)
        {
          stNew.stLAS3[i] = las3.las3Utility.copyWOData( stOld.stLAS3[i] );
        }
      }

      // Unknown Curve Mnemonics

      stNew.sUnknown = new String[4][2];
      for (i=0; i<4; i++)
      {
		for (j=0; j<2; j++)
		{
		  stNew.sUnknown[i][j] = new String( stOld.sUnknown[i][j] );
		}
	  }
	}

    return (stNew);
  }
}
