/*
 * @las3LoadLogData.java Version 1.1 01/22/2010
 *
 * Copyright (c) 2010 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package las3;

import cmn.cmnLASCurveListStruct;
import iqstrat.iqstratHeadersStruct;
import las.lasFileDataStruct;

import las3.las3ListStruct;
import las3.las3Struct;

/** Class las3LoadLogData
 *  <p> This Class will provide load utilities for the LAS 3 Classes
 *
 *  @version 1.1 01/22/2010
 *  @author  John R. Victorine
 */

public class las3LoadLogData
{
  public static final int _NONE        = las3.las3Constants._NONE;

  public static final int _START_DEPTH = 0;
  public static final int _END_DEPTH   = 1;
  public static final int _STEP_BY     = 2;
  public static final int _NULL_VALUE  = 3;

  public static final int _WELL_ROWS  = 4;
  public static final int _WELL_COLS  = 5;
  public static final String WELL[][] = {
  // Mnemonic  Description                    Variations
    { "STRT",  "First Index Value",           "", "", "" },
    { "STOP",  "Last Index Value",            "", "", "" },
    { "STEP",  "STEP of index",               "", "", "" },
    { "NULL",  "NULL VALUE",                  "", "", "" },
  };

  // ~PARAMETER Mnemonics in Well Header

  public static final int _PDAT  = 0;
  public static final int _APD   = 1;
  public static final int _DREF  = 2;
  public static final int _EREF  = 3;
  public static final int _TDL   = 4;
  public static final int _TDD   = 5;
  public static final int _CSGL  = 6;
  public static final int _CSGD  = 7;
  public static final int _CSGS  = 8;
  public static final int _CSGW  = 9;
  public static final int _BS    = 10;
  public static final int _MUD   = 11;
  public static final int _MUDS  = 12;
  public static final int _MUDD  = 13;
  public static final int _MUDV  = 14;
  public static final int _FL    = 15;
  public static final int _PH    = 16;
  public static final int _RM    = 17;
  public static final int _RMT   = 18;
  public static final int _RMF   = 19;
  public static final int _RMFT  = 20;
  public static final int _RMC   = 21;
  public static final int _RMCT  = 22;
  public static final int _TMAX  = 23;
  public static final int _TIMC  = 24;
  public static final int _TIML  = 25;
  public static final int _T_UNIT = 26;
  public static final int _BASE  = 27;
  public static final int _ENG   = 28;
  public static final int _WIT   = 29;
  public static final int _GL    = 30;
  public static final int _KB    = 31;
  public static final int _DF    = 32;
  public static final int _RT    = 33;

  public static final int _PARAM_STD   = 30;
  public static final int _PARAM_ROWS  = 34;
  public static final int _PARAM_COLS  = 5;
  public static final String PARAM[][] = {
 // Mnemonic  Description                      Variations
    { "PDAT",  "Permanent Data",               "PDAT2", "LMF", "" },
    { "APD",   "Above Permanent Data",         "APD2", "", "" },
    { "DREF",  "Depth Reference (KB,DF,CB)",   "", "", "" },
    { "EREF",  "Elevation of Depth Reference", "", "", "" },

    { "TDL",   "Total Depth Logger",           "", "", ""  },
    { "TDD",   "Total Depth Driller",          "TD",   "DRDP", "" },

    { "CSGL",  "Casing Bottom Logger",         "CBD1", "CASL", ""  },
    { "CSGD",  "Casing Bottom Driller",        "CBL1", "CASD", ""  },
    { "CSGS",  "Casing Size",                  "", "", ""  },
    { "CSGW",  "Casing Weight",                "", "", ""  },
    { "BS",    "Bit Size",                     "", "", ""  },
    { "MUD",   "Mud type",                     "FTYP", "", ""  },
    { "MUDS",  "Mud Source",                   "", "", ""  },
    { "MUDD",  "Mud Density",                  "DFD", "", ""  },
    { "MUDV",  "Mud Viscosity (Funnel)",       "DFV", "", ""  },
    { "FL",    "Fluid Loss",                   "DFL", "", ""  },
    { "PH",    "PH",                           "DFPH", "FPH", ""  },
    { "RM",    "Resistivity of Mud",           "MRS", "", ""  },
    { "RMT",   "Temperature of Mud",           "MST", "MTP", ""  },
    { "RMF",   "Resistivity of Mud Filtrate",  "MFRS", "", ""  },
    { "RMFT",  "Temperature of Mud Filtrate",  "MFTP", "", ""  },
    { "RMC",   "Resistivity of Mud Cake",      "MCRS", "", ""  },
    { "RMCT",  "Temperature of Mud Cake",      "MCTP", "", ""  },
    { "TMAX",  "Maximum Recorded Temp.",       "MRT", "", ""  },
    { "TIMC",  "Date/Time Circulation Stopped", "TNOC", "", ""  },
    { "TIML",  "Date/Time Logger Tagged Bottom", "", "", ""  },
    { "UNIT",  "Logging Unit Number",          "LOGU", "", ""  },
    { "BASE",  "Home Base of Logging Unit",    "", "", ""  },
    { "ENG",   "Recording Engineer",           "RECB", "", ""  },
    { "WIT",   "Witnessed By",                 "", "", ""  },
    { "GL",    "Ground Level",                 "EGL", "EGL2", "G.L." },
    { "KB",    "Kelly Bushing",                "EKB", "EKB2", "K.B." },
    { "EDF",   "Drilling Rig Floor",           "EDF2", "DFE", "D.F." },
    { "RT",    "Rotary Table",                 "ERT", "R.T.", "" },
  };

//  MDEN.      2.71               :Density Matrix
//  MATR.      LIMESTONE          :Neutron Matrix
//  DTMT.      49                 :Delta T Matrix
//  DTFL.                         :Delta T Fluid
//  ELCO.      10000              :Electron Cutoff

  public static final int _MNEMONIC      = las3.las3Struct._MNEMONIC;
  public static final int _UNIT          = las3.las3Struct._UNIT;
  public static final int _VALUE         = las3.las3Struct._VALUE;
  public static final int _DESCRIPTION   = las3.las3Struct._DESCRIPTION;
  public static final int _FORMAT        = las3.las3Struct._FORMAT;
  public static final int _ASSOCIATION   = las3.las3Struct._ASSOCIATION;

  /** Method getData()
   * <p> This method will return the LAS File Data Structure from the
   *     LAS 3 Data List Structure.
   * @param  stLAS = the LAS 3 Data List Structure
   * @return st    = the LAS File Data Structure
   */

  public static lasFileDataStruct getData( las3ListStruct stLAS )
  {
    int i,j,k;
    lasFileDataStruct st     = new lasFileDataStruct();
    las3Struct        stH    = null;
    las3Struct        stP    = null;
    int               iWell  = -1;
    int               iParam = -1;

    if (stLAS != null)
    {
      for (i=0; i<stLAS.iCount; i++)
      {
        if (las3.las3Utility.isData( las3.las3Constants._WELL, 0, stLAS ))
          stH = las3.las3Utility.getData( las3.las3Constants._WELL, 0, stLAS );

        if (las3.las3Utility.isData( las3.las3Constants._LOG, 0, stLAS ))
          stP = las3.las3Utility.getData( las3.las3Constants._LOG, 0, stLAS );
      }
    }

    if (stH != null)
    {
      for (i=0; i<stH.iParamRows; i++)
      {
        iWell = _NONE;
        for (j=0; j<_WELL_ROWS; j++)
        {
          for (k=0; k<_WELL_COLS; k++)
          {
            if (stH.sParams[i][_MNEMONIC].toUpperCase().equals(WELL[j][k]))
            {
              iWell = j;

              switch (iWell)
              {
                case _NONE:
                  break;
                case _START_DEPTH:
                  if (cmn.cmnString.isNumeric(stH.sParams[i][_VALUE]))
                    st.depthStart =
                        cmn.cmnString.stringToDouble(stH.sParams[i][_VALUE]);
                  break;
                case _END_DEPTH:
                  if (cmn.cmnString.isNumeric(stH.sParams[i][_VALUE]))
                    st.depthEnd =
                        cmn.cmnString.stringToDouble(stH.sParams[i][_VALUE]);
                  break;
                case _STEP_BY:
                  if (cmn.cmnString.isNumeric(stH.sParams[i][_VALUE]))
                    st.depthStep =
                        cmn.cmnString.stringToDouble(stH.sParams[i][_VALUE]);
                  break;
                case _NULL_VALUE:
                  if (cmn.cmnString.isNumeric(stH.sParams[i][_VALUE]))
                    st.dNull =
                        cmn.cmnString.stringToDouble(stH.sParams[i][_VALUE]);
                  break;
              }
            }
          }
        }
      }
    }

    if (stP != null)
    {
      for (i=0; i<stP.iParamRows; i++)
      {
        iParam = _NONE;
        for (j=0; j<_PARAM_ROWS; j++)
        {
          for (k=0; k<_PARAM_COLS; k++)
          {
            if (stP.sParams[i][_MNEMONIC].toUpperCase().equals(PARAM[j][k]))
            {
              iParam = j;

              switch (iParam)
              {
                case _NONE:
                  break;

                // Required Fields

                case _PDAT:
                  st.sPDAT = new String( stP.sParams[i][_VALUE] );
                  break;
                case _APD:
                  st.dAPD = convertMtoF( stP.sParams[i][_VALUE],
                                         stP.sParams[i][_UNIT] );
                  break;
                case _DREF:
                  st.sDREF = new String( stP.sParams[i][_VALUE] );
                  break;
                case _EREF:
                  st.dElevation = convertMtoF( stP.sParams[i][_VALUE],
                                               stP.sParams[i][_UNIT] );
                  break;

                // Required parameters for AEUB compliance

                case _TDL:
                  if (st.dTLD == 0.0)
                    st.dTLD  = convertMtoF( stP.sParams[i][_VALUE],
                                            stP.sParams[i][_UNIT] );
                  break;
                case _TDD:
                  if (st.dTDD == 0.0)
                    st.dTDD  = convertMtoF( stP.sParams[i][_VALUE],
                                            stP.sParams[i][_UNIT] );
                  break;

                case _CSGL:
                  st.dCSGL = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sCSGL = new String( stP.sParams[i][_UNIT] );
                  break;
                case _CSGD:
                  st.dCSGD = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sCSGD = new String( stP.sParams[i][_UNIT] );
                  break;
                case _CSGS:
                  st.dCSGS = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sCSGS = new String( stP.sParams[i][_UNIT] );
                  break;
                case _CSGW:
                  st.dCSGW = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sCSGW = new String( stP.sParams[i][_UNIT] );
                  break;
                case _BS:
                  st.dBS = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sBS = new String( stP.sParams[i][_UNIT] );
                  break;
                case _MUD:
                  st.sMUD = new String( stP.sParams[i][_VALUE] );
                  break;
                case _MUDS:
                  st.sMUDS = new String( stP.sParams[i][_VALUE] );
                  break;
                case _MUDD:
                  st.dMUDD = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sMUDD = new String( stP.sParams[i][_UNIT] );
                  break;
                case _MUDV:
                  st.dMUDV = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sMUDV = new String( stP.sParams[i][_UNIT] );
                  break;
                case _FL:
                  st.dFL = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sFL = new String( stP.sParams[i][_UNIT] );
                  break;
                case _PH:
                  st.dPH = stringToDouble( stP.sParams[i][_VALUE] );
                  break;
                case _RM:
                  st.dRM = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sRM = new String( stP.sParams[i][_UNIT] );
                  break;
                case _RMT:
                  st.dRMT = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sRMT = new String( stP.sParams[i][_UNIT] );
                  break;
                case _RMF:
                  st.dRMF = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sRMF = new String( stP.sParams[i][_UNIT] );
                  break;
                case _RMFT:
                  st.dRMFT = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sRMFT = new String( stP.sParams[i][_UNIT] );
                  break;
                case _RMC:
                  st.dRMC = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sRMC = new String( stP.sParams[i][_UNIT] );
                  break;
                case _RMCT:
                  st.dRMCT = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sRMCT = new String( stP.sParams[i][_UNIT] );
                  break;
                case _TMAX:
                  st.dTMAX = stringToDouble( stP.sParams[i][_VALUE] );
                  st.sTMAX = new String( stP.sParams[i][_UNIT] );
                  break;
                case _TIMC:
                  st.sTIMC = new String( stP.sParams[i][_VALUE] );
                  break;
                case _TIML:
                  st.sTIML = new String( stP.sParams[i][_VALUE] );
                  break;
                case _T_UNIT:
                  st.sUNIT = new String( stP.sParams[i][_VALUE] );
                  break;
                case _BASE:
                  st.sBASE = new String( stP.sParams[i][_VALUE] );
                  break;
                case _ENG:
                  st.sENG = new String( stP.sParams[i][_VALUE] );
                  break;
                case _WIT:
                  st.sWIT = new String( stP.sParams[i][_VALUE] );
                  break;
                default:
                  break;
              }
            }
          }
        }
      }
    }

    return (st);
  }

  /** Method initData()
   * <p> This method will initialize the LAS File Data Structure Lot Data Arrays
   * @param  iRows = Total Number of Rows
   * @param  stLAS = LAS File Data Structure
   * @return stLAS = LAS File Data Structure
   */

  public static lasFileDataStruct initData( int iRows, lasFileDataStruct stLAS )
  {
    int i=0;

    if ((stLAS != null) && (iRows > 0))
    {
      stLAS.iRows     = iRows;                   // Number of Rows

      stLAS.depths    = new double[stLAS.iRows]; // Array of Depth Data Values

      stLAS.dCAL1     = new double[stLAS.iRows]; // Array of Caliper 1 Log Values
      stLAS.dCAL2     = new double[stLAS.iRows]; // Array of Caliper 2 Log Values
      stLAS.dCAL3     = new double[stLAS.iRows]; // Array of Caliper 3 Log Values
      stLAS.dCAL4     = new double[stLAS.iRows]; // Array of Caliper 4 Log Values
      stLAS.dCAL5     = new double[stLAS.iRows]; // Array of Caliper 5 Log Values
      stLAS.dCAL6     = new double[stLAS.iRows]; // Array of Caliper 6 Log Values

      stLAS.dAZIC1    = new double[stLAS.iRows]; // Array of Azimuth degrees for pad 1 Log Values

      for (i=0; i<stLAS.iRows; i++)
      {
        stLAS.depths[i]    = stLAS.dNull; // Array of Depth Data Values

        stLAS.dCAL1[i]     = stLAS.dNull; // Array of Caliper 1 Log Values
        stLAS.dCAL2[i]     = stLAS.dNull; // Array of Caliper 2 Log Values
        stLAS.dCAL3[i]     = stLAS.dNull; // Array of Caliper 3 Log Values
        stLAS.dCAL4[i]     = stLAS.dNull; // Array of Caliper 4 Log Values
        stLAS.dCAL5[i]     = stLAS.dNull; // Array of Caliper 5 Log Values
        stLAS.dCAL6[i]     = stLAS.dNull; // Array of Caliper 6 Log Values

        stLAS.dAZIC1[i]    = stLAS.dNull; // Array of Azimuth degrees for pad 1 Log Values
      }

      if (stLAS.depthStep > 0.0)
      {
        for (i=0; i<stLAS.iRows; i++)
        {
          stLAS.depths[i] = stLAS.depthStart + i * stLAS.depthStep;
        }
      }
    }

    return (stLAS);
  }

  /** Method addData()
   * <p> This method will add the LAS 3 Data Structure to the LAS Data Structure
   * @param  sData = Array of Log Data From each row
   * @param  iColumns = Total number of Log Curves
   * @param  stC   = LAS File Data Structure - File Curve Order Matched to type
   * @param  stLAS = LAS File Data Structure
   * @return stLAS = LAS File Data Structure
   */

  public static lasFileDataStruct addData( String            sData[],
                                           int               iColumns,
                                           lasFileDataStruct stC,
                                           lasFileDataStruct stLAS )
  {
    int    iRow     = -1;
    double data     = 0.0;
    double dRange[] = { 0.0, 0.0 };
    double diff     = 0.0;

    if (sData != null)
    {
      iRow = -1;
      data = stringToDouble( sData[0], stLAS.dNull );
      for (int i=0; i<stLAS.iRows; i++)
      {
        diff = Math.abs( data - stLAS.depths[i] );
//        if (data == stLAS.depths[i])
        if ( diff < .00001 )
          iRow = i;
      }

      if (iRow > -1)
      {
        for (int j=1; j<iColumns; j++)
        {
          data = stringToDouble(sData[j], stLAS.dNull);

          // Depth Data Values
          if (j == 0)
            stLAS.depths[iRow] = data;

          if (stC.iCAL1 == j) // Caliper 1
            stLAS.dCAL1[iRow] = data;
          if (stC.iCAL2 == j) // Caliper 2
            stLAS.dCAL2[iRow] = data;
          if (stC.iCAL3 == j) // Caliper 3
            stLAS.dCAL3[iRow] = data;
          if (stC.iCAL4 == j) // Caliper 4
            stLAS.dCAL4[iRow] = data;
          if (stC.iCAL5 == j) // Caliper 5
            stLAS.dCAL5[iRow] = data;
          if (stC.iCAL6 == j) // Caliper 6
            stLAS.dCAL6[iRow] = data;

          if (stC.iAZIC1 == j) // Caliper Azimuth if pad 1
            stLAS.dAZIC1[iRow] = data;
        }
      }
    }

    return (stLAS);
  }

  /** Method setData()
   * <p> This method will return the LAS 3 Data List Structure from the
   *     LAS File Data List Structure.
   * @param  st    = the LAS File Data Structure
   * @param  dNull = LAS 3 File Data Null Value
   * @return stT   = the LAS 3 Data Structure
   */

  public static las3Struct setData( lasFileDataStruct st, double dNull )
  {
    las3Struct stT = null;

    if (st != null)
    {
      stT        = new las3Struct();
      stT.iType  = las3.las3Constants._LOG;
      stT.iArray = 0;
      stT.sType  = new String(las3.las3Constants.SECTIONS[stT.iType]);

      stT        = addParameters( st, stT );    // Add the Required Parameters
//      stT        = addCurves( st, stT, dNull ); // Add Curves
    }

    return (stT);
  }

  /** Method addParameters()
   * <p> This method will add the Parameter Data to the LAS 3 File Data Structure
   * @param  st    = the LAS File Data List Structure
   * @param  stT   = the LAS 3 File Data Structure
   * @return stT   = the LAS 3 File Data Structure
   */

  public static las3Struct addParameters( lasFileDataStruct st, las3Struct stT)
  {
    int i,j;
    String sDate[] = { "", "" };

    if ((st != null) && (stT != null))
    {
      stT.iParamRows  = las3.las3Parameters._LOG_TOTAL;  // Total number of rows
      stT.iParamCols  = las3.las3Struct._TOTAL; // Total number of columns
      stT.sParams = new String[stT.iParamRows][stT.iParamCols];

      for (i=0; i<stT.iParamRows; i++)
      {
        for (j=0; j<las3.las3Struct._TOTAL; j++)
        {
          stT.sParams[i][j] = new String("");
        }
      }

      for (i=0; i<stT.iParamRows; i++)
      {
        stT.sParams[i][_MNEMONIC] =
            new String( las3.las3Parameters.LOG_PARAMETERS[i][0] );
        stT.sParams[i][_UNIT]     =
            new String( las3.las3Parameters.LOG_PARAMETERS[i][1] );
        stT.sParams[i][_VALUE]    =  new String( "" );
        stT.sParams[i][_DESCRIPTION] =
            new String( las3.las3Parameters.LOG_PARAMETERS[i][3] );
        stT.sParams[i][_FORMAT]      =
            new String( las3.las3Parameters.LOG_PARAMETERS[i][4] );

        switch (i)
        {
            // Required Fields

            case las3.las3Parameters._PDAT:
              stT.sParams[i][_VALUE] = new String( st.sPDAT );
              break;
            case las3.las3Parameters._APD:
              stT.sParams[i][_VALUE] = new String( "" + st.dAPD );
              break;
            case las3.las3Parameters._DREF:
              stT.sParams[i][_VALUE] = new String( st.sDREF );
              break;
            case las3.las3Parameters._EREF:
              stT.sParams[i][_VALUE] = new String( "" + st.dElevation );
              break;

            case las3.las3Parameters._RUN:
              stT.sParams[i][_VALUE] = new String( "1" );
              break;

            // Required parameters for AEUB compliance

            case las3.las3Parameters._TDL:
              if (st.dTLD > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dTLD );
              break;
            case las3.las3Parameters._TDD:
              if (st.dTDD > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dTDD );
              break;

            case las3.las3Parameters._CSGL:
              if (st.dCSGL > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dCSGL );
              break;
            case las3.las3Parameters._CSGD:
              if (st.dCSGD > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dCSGD );
              break;
            case las3.las3Parameters._CSGS:
              if (st.dCSGS > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dCSGS );
              break;
            case las3.las3Parameters._CSGW:
              if (st.dCSGW > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dCSGW );
              break;
            case las3.las3Parameters._BS:
              if (st.dBS > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dBS );
              break;
            case las3.las3Parameters._MUD:
              stT.sParams[i][_VALUE] = new String( st.sMUD );
              break;
            case las3.las3Parameters._MUDS:
              stT.sParams[i][_VALUE] = new String( st.sMUDS );
              break;
            case las3.las3Parameters._MUDD:
              if (st.dMUDD > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dMUDD );
              break;
            case las3.las3Parameters._MUDV:
              if (st.dMUDV > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dMUDV );
              break;
            case las3.las3Parameters._FL:
              if (st.dFL > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dFL );
              break;
            case las3.las3Parameters._PH:
              if (st.dPH > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dPH );
              break;
            case las3.las3Parameters._RM:
              if (st.dRM > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dRM );
              break;
            case las3.las3Parameters._RMT:
              if (st.dRMT > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dRMT );
              break;
            case las3.las3Parameters._RMF:
              if (st.dRMF > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dRMF );
              break;
            case las3.las3Parameters._RMFT:
              if (st.dRMFT > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dRMFT );
              break;
            case las3.las3Parameters._RMC:
              if (st.dRMC > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dRMC );
              break;
            case las3.las3Parameters._RMCT:
              if (st.dRMCT > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dRMCT );
              break;
            case las3.las3Parameters._TMAX:
              if (st.dTMAX > 0.0)
                stT.sParams[i][_VALUE] = new String( "" + st.dTMAX );
              break;
            case las3.las3Parameters._TIMC:
              stT.sParams[i][_VALUE] = new String( st.sTIMC );
              break;
            case las3.las3Parameters._TIML:
              stT.sParams[i][_VALUE] = new String( st.sTIML );
              break;
            case las3.las3Parameters._T_UNIT:
              stT.sParams[i][_VALUE] = new String( st.sUNIT );
              break;
            case las3.las3Parameters._BASE:
              stT.sParams[i][_VALUE] = new String( st.sBASE );
              break;
            case las3.las3Parameters._ENG:
              stT.sParams[i][_VALUE] = new String( st.sENG );
              break;
            case las3.las3Parameters._WIT:
              stT.sParams[i][_VALUE] = new String( st.sWIT );
              break;
        }
      }
    }

    return (stT);
  }

  /** Method mergeLogData()
   * <p> This method will merge a LAS File Data Structure with the new LAS
   *     File Data Structure
   * @param  st    = LAS File Data Structure
   * @param  stLAS = LAS File Data Structure
   * @return stLAS = LAS File Data Structure
   */

  public static lasFileDataStruct mergeLogData( lasFileDataStruct st,
                                                lasFileDataStruct stLAS )
  {
    double depth  = 0.0;
    double depth1 = 0.0;
    double data1  = 0.0;
    double depth2 = 0.0;
    double data2  = 0.0;
    double dTemp  = 0.0;
    int    iTemp  = 0;

    for (int k=0; k<las.lasStandardTools.TOTAL; k++)
    {
      switch (k)
      {
        case las.lasStandardTools._CAL1:
          if (st.iCAL1 > -1) stLAS.iCAL1 = st.iCAL1;
          break;

        case las.lasStandardTools._CAL2:
          if (st.iCAL2 > -1) stLAS.iCAL2 = st.iCAL2;
          break;

        case las.lasStandardTools._CAL3:
          if (st.iCAL3 > -1) stLAS.iCAL3 = st.iCAL3;
          break;

        case las.lasStandardTools._CAL4:
          if (st.iCAL4 > -1) stLAS.iCAL4 = st.iCAL4;
          break;

        case las.lasStandardTools._CAL5:
          if (st.iCAL5 > -1) stLAS.iCAL5 = st.iCAL5;
          break;

        case las.lasStandardTools._CAL6:
          if (st.iCAL6 > -1) stLAS.iCAL6 = st.iCAL6;
          break;

        case las.lasStandardTools._AZIC1:
          if (st.iAZIC1 > -1) stLAS.iAZIC1 = st.iAZIC1;
          break;
      }
    }

    if ((st != null) && (stLAS != null))
    {
      for (int j=0; j<stLAS.iRows; j++)
      {
        depth  = stLAS.depths[j];

        for (int i=0; i<st.iRows-1; i++)
        {
          depth1 = st.depths[i];
          depth2 = st.depths[i+1];

          if ((depth >= depth1) && (depth < depth2))
          {
            for (int k=0; k<las.lasStandardTools.TOTAL; k++)
            {
              if (st.checkData(k))
              {
                data1  = st.getRow( k, i );
                data2  = st.getRow( k, i+1 );

                if ((data1 > st.dNull) && (data2 > st.dNull))
                {
                  dTemp = data2 -
                            ((data2-data1) * (depth2-depth)) / (depth2-depth1);

                  iTemp = (int) (dTemp * 1000.0);

                  stLAS.setRow( k, j, (double) iTemp / 1000.0 );
                }
                else
                  stLAS.setRow( k, j, st.dNull );
              }
            }
          }
        }
      }
    }

    return (stLAS);
  }

  /** Method isDepth()
   * <p> This method will determine if the depth is already in the LAS File or
   *     Not
   * @param  depth    = depth being tested
   * @param  iRows    = total number of depths
   * @param  depths   = array of depths in the LAS File Data Structure
   * @return bValue   = true the depth is present, false it is a new depth
   */

  public static boolean isDepth( double depth, int iRows, double depths[] )
  {
    boolean bValue = false;

    for (int i=0; i<iRows; i++)
    {
      if (depth == depths[i])
      {
        bValue = true;
      }
    }

    return (bValue);
  }

  /** Method stringToDouble()
   * <p> This method will convert the String to double.  This first checks to
   *     see if the string is numeric and then passes the data back
   * @param  str    = the string to be converted
   * @return dValue = double value of the string passed in or Null value
   */

  public static double stringToDouble( String str )
  {
    double dValue = 0.0;

    if (str != null)
    {
      if (cmn.cmnString.isNumeric( str ))
        dValue = cmn.cmnString.stringToDouble( str );
    }

    return (dValue);
  }

  /** Method stringToDouble()
   * <p> This method will convert the String to double.  This first checks to
   *     see if the string is numeric and then passes the data back, but uses
   *     the Null Value if it is not a valid number
   * @param  str    = the string to be converted
   * @param  dNull  = the LAS File Null Value
   * @return dValue = double value of the string passed in or Null value
   */

  public static double stringToDouble( String str, double dNull )
  {
    double dValue = dNull;

    if (str != null)
    {
      if (cmn.cmnString.isNumeric( str ))
        dValue = cmn.cmnString.stringToDouble( str );
    }

    return (dValue);
  }

  /** Method convertMtoF()
   * <p> This method will convert meters to feet
   * @param  str    = the text to be converted
   * @param  sUnit  = the unit
   * @return dValue = depth in feet
   */

  public static double convertMtoF(String str, String sUnit)
  {
    double dValue = 0.0;
    double dFeet  = 3.281;
    int    iValue = 0;

    if (str.length() > 0)
    {
      if (cmn.cmnString.isNumeric( str.trim() ))
      {
        dValue = cmn.cmnString.stringToDouble( str.trim() );

        if (sUnit.equals("M"))
          dValue = dFeet * dValue;

        iValue = (int) (dValue * 1000.0);
        dValue = (double) iValue / 1000.0;
      }
    }

    return (dValue);
  }

  /** Method normalizeDepth()
   * <p> This method will convert meters to feet
   * @param  st  = Well Header Data Structure
   * @param  stL = LAS File Data Structure
   * @return st  = Well Header Data Structure
   */

  public static lasFileDataStruct normalizeDepth(
      iqstratHeadersStruct st, lasFileDataStruct stL )
  {
//    double diff = 15.0;  // Height of Kelly Bushing above Ground Level in ft
    double diff = 0.0;  // Height above Ground Level in ft

    if ((st != null) && (stL != null))
    {
      if (stL.sPDAT.length() == 0)
      {
        if ((st.dGL > 0.0) && (st.dKB > 0.0))
        {
          diff = Math.abs(st.dKB - st.dGL);

          stL.sPDAT      = new String( "GL" );  // Permanent Data
          stL.dAPD       = diff;                // Above Permanent Data
          stL.sDREF      = new String( "KB" );  // Depth Reference (KB,DF,CB)
          stL.dElevation = st.dKB;              // "Elevation of Depth Reference"
        }
        else if ((st.dGL > 0.0) && (st.dDF > 0.0))
        {
          diff = Math.abs(st.dDF - st.dGL);

          stL.sPDAT      = new String( "GL" );  // Permanent Data
          stL.dAPD       = diff;                // Above Permanent Data
          stL.sDREF      = new String( "DF" );  // Depth Reference (KB,DF,CB)
          stL.dElevation = st.dDF;              // "Elevation of Depth Reference"
        }
        else if (st.dGL > 0.0)
        {
          stL.sPDAT      = new String( "GL" );  // Permanent Data
          stL.dAPD       = 0.0;                 // Above Permanent Data
          stL.sDREF      = new String( "GL" );  // Depth Reference (KB,DF,CB)
          stL.dElevation = st.dGL;              // "Elevation of Depth Reference"
        }
        else if (st.dKB > 0.0)
        {
          stL.sPDAT      = new String( "GL" );  // Permanent Data
          stL.dAPD       = 15.0;                // Above Permanent Data
          stL.sDREF      = new String( "KB" );  // Depth Reference (KB,DF,CB)
          stL.dElevation = st.dKB - stL.dAPD;   // "Elevation of Depth Reference"
        }
        else if (st.dDF > 0.0)
        {
          stL.sPDAT      = new String( "GL" );  // Permanent Data
          stL.dAPD       = 15.0;                // Above Permanent Data
          stL.sDREF      = new String( "DF" );  // Depth Reference (KB,DF,CB)
          stL.dElevation = st.dDF - stL.dAPD;   // "Elevation of Depth Reference"
        }
      }

      if ((st.depth > 0.0) && (stL.dTLD == 0.0))
        stL.dTLD = st.depth;
    }

    return (stL);
  }
}

/*
 *  @version 1.1 01/22/2010
 *  @author  John Victorine
 */
